from sqlalchemy import String, Column, Integer, DateTime, JSON, create_engine, Text

from app.modle import Base
from app.utils.util import cn_now


class FloorConfiguration(Base):
    """楼层表地图信息配置"""

    __tablename__ = 'FloorConfiguration'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=False, unique=False, index=False, doc='配置名称')
    location = Column(String, nullable=True, unique=False, index=False, doc='楼层位置')
    use = Column(String, nullable=True, unique=False, index=False, doc='楼层用途')
    remark = Column(String, nullable=True, unique=False, index=False, doc='备注')
    attachment = Column(String, nullable=True, unique=False, index=False, doc='附件')
    account = Column(String, nullable=True, unique=False, index=False, doc='上传账户')
    time = Column(String, nullable=True, unique=False, index=False, default=cn_now(), doc='上传时间')


class FloorConfigurationHistory(Base):
    """楼层表地图信息配置历史记录"""

    __tablename__ = 'FloorConfigurationHistory'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    floor_configuration = Column(Integer, nullable=False, unique=False, index=False, doc='楼层表地图信息配置id')
    url = Column(String, nullable=False, unique=False, index=False, default={}, doc='图片url列表')


class StaffConfiguration(Base):
    """安保人员信息配置"""

    __tablename__ = 'StaffConfiguration'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=False, unique=False, index=False, doc='配置名称')
    # personnel_type = Column(String, nullable=True, unique=False, index=False, doc='人员类别')
    # responsibility_range = Column(String, nullable=True, unique=False, index=False, doc='职责范围')
    # staff_list = Column(String, nullable=True, unique=False, index=False, doc='人员名单')
    # remark = Column(String, nullable=True, unique=False, index=False, doc='备注')
    # duty_time = Column(JSON, nullable=True, unique=False, index=False, doc="值班日期：{'start_time': '', end_time: ''}")


class StaffConfigurationStaff(Base):
    """安保人员信息配置人员"""

    __tablename__ = 'StaffConfigurationStaff'
    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    Configuration_id = Column(String, nullable=True, unique=False, index=False, doc='配置id')
    responsibility_range = Column(String, nullable=True, unique=False, index=False, doc='职责范围')
    staff = Column(String, nullable=True, unique=False, index=False, doc='人员')
    remark = Column(String, nullable=True, unique=False, index=False, doc='备注')
    duty_time = Column(JSON, nullable=True, unique=False, index=False, doc="值班日期：{'start_time': '', end_time: ''}")
    update_time = Column(String, nullable=True, unique=False, index=False, doc='更新时间')
    staff_details = Column(Text, nullable=True, unique=False, index=False, doc='人员信息')


# class StaffConfigurationHistory(Base):
#     """安保人员信息配置历史记录"""
#
#     __tablename__ = 'StaffConfigurationHistory'
#
#     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
#     configuration_id = Column(String, nullable=True, unique=False, index=False, doc='配置id')
#     staff_list = Column(String, nullable=True, unique=False, index=False, doc='人员名单')
#     duty_time = Column(JSON, nullable=True, unique=False, index=False, doc="值班日期：{'start_time': '', end_time: ''}")


class SecurityPerson(Base):
    """人员表"""

    __tablename__ = 'person'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=True, unique=False, index=False, doc='姓名')
    phone = Column(String, nullable=True, unique=False, index=False, doc='手机号')
    type = Column(Integer, nullable=True, unique=False, index=False, doc='人员类型 * 0 正式员工  1 外协员工 2 驻场物业3 施工人员 4 厂商 5 其他')
    status = Column(Integer, nullable=True, unique=False, index=False, doc=' 0 正常1 已离职2 暂时冻结')
    is_del = Column(Integer, nullable=True, unique=False, index=False, doc='')
    company_id = Column(Integer, nullable=True, unique=False, index=False, doc='')
    company_name = Column(String, nullable=True, unique=False, index=False, doc='')
    dept_id = Column(Integer, nullable=True, unique=False, index=False, doc='')
    dept_name = Column(String, nullable=True, unique=False, index=False, doc='')
    create_time = Column(DateTime, nullable=True, unique=False, index=False, doc='')
    update_time = Column(DateTime, nullable=True, unique=False, index=False, doc='')
    email = Column(String, nullable=True, unique=False, index=False, doc='邮箱')
    duty = Column(String, nullable=True, unique=False, index=False, doc='职务')
    hiredate = Column(DateTime, nullable=True, unique=False, index=False, doc='入职时间')
    address = Column(String, nullable=True, unique=False, index=False, doc='家庭住址')
    function_type = Column(String, nullable=True, unique=False, index=False, doc='职能类型')
    hr_number = Column(String, nullable=True, unique=False, index=False, doc='HR编号')
    work_address = Column(String, nullable=True, unique=False, index=False, doc='办公驻地')
    floor = Column(String, nullable=True, unique=False, index=False, doc='办公楼层')
    zy_number = Column(String, nullable=True, unique=False, index=False, doc='主语人员编码')
    room_number = Column(String, nullable=True, unique=False, index=False, doc='房间号')
    site_number = Column(String, nullable=True, unique=False, index=False, doc='工位号')
    id_card = Column(String, nullable=True, unique=False, index=False, doc='身份证号')
    physics_card = Column(String, nullable=True, unique=False, index=False, doc='物理卡号')
    account = Column(String, nullable=True, unique=False, index=False, doc='消费账号')
    car_number = Column(String, nullable=True, unique=False, index=False, doc='车牌号')
    role = Column(String, nullable=True, unique=False, index=False, doc='角色')
    operate_status = Column(String, nullable=True, unique=False, index=False, doc='操作状态')
    issue_status = Column(String, nullable=True, unique=False, index=False, doc='下发状态')
    impower_time = Column(DateTime, nullable=True, unique=False, index=False, doc='授权时间')
    in_out = Column(String, nullable=True, unique=False, index=False, doc='出入口权限')
    access = Column(String, nullable=True, unique=False, index=False, doc='门禁权限')
    card_number = Column(String, nullable=True, unique=False, index=False, doc='卡片编号')
